fnss.topologies.topology.DirectedTopology.has_node — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »

# fnss.topologies.topology.DirectedTopology.has_node

`DirectedTopology.` `has_node`(n)

  Return True if the graph contains the node n.

  Parameters : | n : node

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2])
      >>> G.has_node(0)
      True

  It is more readable and simpler to use

      >>> 0 in G
      True

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »